FadeOut

Struct FadeOut 

pub struct FadeOut<T: FadingRequirement> {
    src: T,
    dst: T,
}
Fade-out animation.

Because some Items may not be completly opaque, so this is implemented by setting the opacity to 0.0 as target state, then interpolate between them.

Fields

src: Tdst: T

Implementations

Source

impl<T: FadingRequirement> FadeOut<T>

pub fn new(target: T) -> Self

Constructor